package com.tongran.system.service;

import com.tongran.system.domain.RmMonitorConfig;

import java.util.List;

/**
 * 监控配置Service接口
 * 
 * @author tongran
 * @date 2025-11-12
 */
public interface IRmMonitorConfigService 
{
    /**
     * 查询监控配置
     * 
     * @param id 监控配置主键
     * @return 监控配置
     */
    public RmMonitorConfig selectRmMonitorConfigById(Long id);

    /**
     * 查询监控配置列表
     * 
     * @param rmMonitorConfig 监控配置
     * @return 监控配置集合
     */
    public List<RmMonitorConfig> selectRmMonitorConfigList(RmMonitorConfig rmMonitorConfig);

    /**
     * 新增监控配置
     * 
     * @param rmMonitorConfig 监控配置
     * @return 结果
     */
    public int insertRmMonitorConfig(RmMonitorConfig rmMonitorConfig);

    /**
     * 修改监控配置
     * 
     * @param rmMonitorConfig 监控配置
     * @return 结果
     */
    public int updateRmMonitorConfig(RmMonitorConfig rmMonitorConfig);

    /**
     * 批量删除监控配置
     * 
     * @param ids 需要删除的监控配置主键集合
     * @return 结果
     */
    public int deleteRmMonitorConfigByIds(Long[] ids);

    /**
     * 删除监控配置信息
     * 
     * @param id 监控配置主键
     * @return 结果
     */
    public int deleteRmMonitorConfigById(Long id);

    public void sumTrafficMyMonitorConfig(Long id);

    void asyncAfterInsert(Long id);
}
